===================================
CKEditor for Django admin
===================================

**CKEditor (WYSIWYG editor) integration app for Django admin**.

http://ckeditor.com/


Documentation
=============

See `Django Suit documentation <http://django-suit.readthedocs.org/en/develop/wysiwyg.html>`_ on WYSIWYG editors.


Build Status
============

Django Suit CKeditor app uses Travis CI to perform tests on different Django and Python versions.

.. |master| image:: https://travis-ci.org/darklow/django-suit-ckeditor.png?branch=master
   :alt: Build Status - master branch
   :target: http://travis-ci.org/darklow/django-suit-ckeditor

|master|
